@@ -363,41 +363,41 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
                 }
             }
 
-            #[endpoint {
-                method = PATCH,
-                path = "/checkout/{id}/initiate_payment",
-            }]
-            pub async fn initiate_payment_endpoint(
-                req_ctx: Arc<RequestContext<ServerContext>>,
-                path: Path<IdParam>,
-                body: TypedBody<<super::#context_type_name as PaymentProcessor>::InitiateArgs>,
-            ) -> Result<HttpResponseOk<Checkout>, HttpError> {
-                let path_params = path.into_inner();
-                let args = body.into_inner();
-                let mut ctx = req_ctx
-                    .context()
-                    .context_provider
-                    .new_context()
-                    .await
-                    .unwrap();
+            // #[endpoint {
+            //     method = PATCH,
+            //     path = "/checkout/{id}/initiate_payment",
+            // }]
+            // pub async fn initiate_payment_endpoint(
+            //     req_ctx: Arc<RequestContext<ServerContext>>,
+            //     path: Path<IdParam>,
+            //     body: TypedBody<<super::#context_type_name as PaymentProcessor>::InitiateArgs>,
+            // ) -> Result<HttpResponseOk<Checkout>, HttpError> {
+            //     let path_params = path.into_inner();
+            //     let args = body.into_inner();
+            //     let mut ctx = req_ctx
+            //         .context()
+            //         .context_provider
+            //         .new_context()
+            //         .await
+            //         .unwrap();
 
-                ctx.start_transaction().await.unwrap();
-                match initiate_payment_handler(&mut ctx, &path_params.id, args).await {
-                    Ok(co) => {
-                        ctx.commit_transaction().await.unwrap();
-                        Ok(HttpResponseOk(co))
-                    }
-                    Err(err) => {
-                        ctx.abort_transaction().await.unwrap();
-                        Err(HttpError {
-                            status_code: StatusCode::BAD_REQUEST,
-                            error_code: Some(err.code.clone()),
-                            external_message: err.message.clone(),
-                            internal_message: err.message.clone(),
-                        })
-                    }
-                }
-            }
+            //     ctx.start_transaction().await.unwrap();
+            //     match initiate_payment_handler(&mut ctx, &path_params.id, args).await {
+            //         Ok(co) => {
+            //             ctx.commit_transaction().await.unwrap();
+            //             Ok(HttpResponseOk(co))
+            //         }
+            //         Err(err) => {
+            //             ctx.abort_transaction().await.unwrap();
+            //             Err(HttpError {
+            //                 status_code: StatusCode::BAD_REQUEST,
+            //                 error_code: Some(err.code.clone()),
+            //                 external_message: err.message.clone(),
+            //                 internal_message: err.message.clone(),
+            //             })
+            //         }
+            //     }
+            // }
         }
 
         #[async_trait]
@@ -413,7 +413,9 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
                 api.register(checkout_server::update_contact_endpoint).unwrap();
                 api.register(checkout_server::update_shipping_address_endpoint).unwrap();
                 api.register(checkout_server::update_fulfillment_type_endpoint).unwrap();
-                api.register(checkout_server::initiate_payment_endpoint).unwrap();
+                // api.register(checkout_server::initiate_payment_endpoint).unwrap();
+
+                api
             }
 
             async fn new_server(
